LinearRelations Example
===============================================================================

:download:`linear_relations.enaml <../../../examples/layout/basic/linear_relations.enaml>`

.. literalinclude:: ../../../examples/layout/basic/linear_relations.enaml
    :language: python

::

 $ enaml-run linear_relations.enaml

.. image:: images/linear_relations.png
